summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmsqeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmsqeedit.h')
-rw-r--r--kpovmodeler/pmsqeedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmsqeedit.h b/kpovmodeler/pmsqeedit.h
index 6cde9fc4..4f870ced 100644
--- a/kpovmodeler/pmsqeedit.h
+++ b/kpovmodeler/pmsqeedit.h
@@ -39,9 +39,9 @@ class PMSuperquadricEllipsoidEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSuperquadricEllipsoidEdit with tqparent and name
*/
- PMSuperquadricEllipsoidEdit( TQWidget* tqparent, const char* name = 0 );
+ PMSuperquadricEllipsoidEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMSuperquadricEllipsoidEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMSuperquadricEllipsoidEdit with tqparent and name
+ * Creates a PMSuperquadricEllipsoidEdit with parent and name
*/